@@ -53,7 +53,7 @@ model = Neural_Network(preprocessor=pp,
 # cb_model = ModelCheckpoint("submission_model.hdf5", monitor="loss",
 #                         c   verbose=1, save_best_only=True, mode="min")
 
-# model.train(indices_list[0:1], epochs=100, iterations=10, callbacks=[])
+model.train(indices_list[0:1], epochs=100, iterations=10, callbacks=[])
 
 # model.dump("lol")
 # model.load("lol")
